# dtarot
Discordian Tarot program

## Usage
dtarot [-m]

Prints your (or someone else's) super-helpful Discordian Tarot reading.
Adding the -m argument also provides putative meanings for the cards, for those
 unfamiliar with this deck. Of course, you're free to add whatever meaning
 you'd like; all things are true|false|meaningless anyway.

## Credits
Original Discordian Tarot Deck by Max Flax Beeblewax and (boing!) Cnoocy Mosque O'Witz (marc@suberic.net).
(NOTE: I have no idea if that e-mail address still works.)

Python program by Lord Imbrius the Despondent (darthferrett@gmail.com).
(NOTE: I also have no idea if that e-mail address still works - e-mail me and find out!)

## Note
For further enlightenment, consult your pineal gland.
